# ThaiTextAug

Thai Text Augmentation: Thai Text Augmentation Tool

## Install

```sh
pip install thaitextaug
```

for fasttext

```sh
pip install thaitextaug[fasttext]
```

for all

```sh
pip install thaitextaug[all]
```

## Docs

You can read The API docs at [github.wannaphong.com/thaitextaug](https://github.wannaphong.com/thaitextaug/index.html)

Tutorials Notebook: [notebooks](https://github.com/wannaphong/thaitextaug/tree/main/notebooks)
